@@ -3,4 +3,5 @@ from enum import Enum
 
 class SupportedPlatforms(Enum):
     # supportedOS
-    supportedOS = ["Linux","Windows"]
+    supportedOS = ["Linux", "Darwin","Windows"]
+
